Ligdicash class

Classe principale pour interagir avec l'API de Ligdicash.

Constructors

Ligdicash({required String apikey, required String authToken, required PlatformType platform, String? baseUrl})
Crée une instance de Ligdicash avec les paramètres spécifiés.

Properties

apikey String
La clé API pour l'authentification.
final
authToken String
Le jeton d'authentification pour l'API.
final
baseUrl String
L'URL de base de l'API.
final
hashCode int
The hash code for this object.
no setterinherited
platform → PlatformType
La plateforme utilisée pour envoyer des requêtes HTTP.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getTransaction({required String token, TransactionType type = TransactionType.payin}) Future<StatusResponse>
Récupère une transaction à partir d'un jeton.
Invoice({required String currency, required String description, required String customerFirstname, required String customerLastname, required String customerEmail, required String storeName, required String storeWebsiteUrl}) → Invoice
Crée une instance de Invoice pour générer une facture.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
Withdrawal({required double amount, required String description, required String customer}) → Withdrawal
Crée une instance de Withdrawal pour effectuer une demande de retrait d'argent.

Operators

operator ==(Object other) bool
The equality operator.
inherited